The three interfaces to Caustics
================================

There are three user interfaces to Caustics: configuration file, object-oriented, and functional.
Here we have built the same tutorial three times over so you can see how the three interfaces compare.
They provide progressively more freedom and power, but also require more knowledge of the underlying system.

1. Configuration File: :doc:`tutorials/InterfaceIntroduction_yaml`
2. Object-Oriented: :doc:`tutorials/InterfaceIntroduction_oop`
3. Functional: :doc:`tutorials/InterfaceIntroduction_func`
